GO-PCA Demos
============

.. note:: Under construction! Additional demo notebooks will be available here shortly.

This page contains a list of Juypter (IPython) notebooks demonstrating the application of GO-PCA to various datasets.

DMAP - Human hematopoeitic lineages
-----------------------------------

- `Demo_DMAP.ipynb`__ (:download:`download <notebooks/Demo_DMAP.ipynb>`)

This notebook demonstrates the application of GO-PCA to the ``DMAP`` dataset (`Novershtern et al., 2011`__), consisting of 211 samples that represent various human hematopoeitic lineages.

__ demo_DMAP_
__ dmap_paper_

.. _demo_DMAP: http://nbviewer.ipython.org/url/gopca.readthedocs.org/en/latest/_downloads/Demo_DMAP.ipynb
.. _dmap_paper: http://www.ncbi.nlm.nih.gov/pubmed/21241896



